==> valentina_0.7.49~dfsg.orig.tar.xz: valentina-v0.7.49/src/app/tape/dialogs/configpages/tapepreferencesconfigurationpage.h <==
/************************************************************************
 **
 **  @file   tapepreferencesconfigurationpage.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   12 4, 2017
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2017 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/

#ifndef TAPEPREFERENCESCONFIGURATIONPAGE_H
#define TAPEPREFERENCESCONFIGURATIONPAGE_H

#include <QWidget>

namespace Ui
{
    class TapePreferencesConfigurationPage;
}

class TapePreferencesConfigurationPage : public QWidget
{
    Q_OBJECT

public:
    explicit TapePreferencesConfigurationPage(QWidget *parent = nullptr);
    virtual ~TapePreferencesConfigurationPage();

    QStringList Apply();
protected:
    virtual void changeEvent(QEvent* event) override;
private:
    Q_DISABLE_COPY(TapePreferencesConfigurationPage)
    Ui::TapePreferencesConfigurationPage *ui;
    bool m_langChanged;
    bool m_systemChanged;

    void RetranslateUi();
};

#endif // TAPEPREFERENCESCONFIGURATIONPAGE_H

==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/app/tape/dialogs/configpages/tapepreferencesconfigurationpage.h <==
/************************************************************************
 **
 **  @file   tapepreferencesconfigurationpage.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   12 4, 2017
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2017 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/

#ifndef TAPEPREFERENCESCONFIGURATIONPAGE_H
#define TAPEPREFERENCESCONFIGURATIONPAGE_H

#include <QWidget>

#include "../vmisc/defglobal.h"

namespace Ui
{
    class TapePreferencesConfigurationPage;
}

class TapePreferencesConfigurationPage : public QWidget
{
    Q_OBJECT // NOLINT

public:
    explicit TapePreferencesConfigurationPage(QWidget *parent = nullptr);
    ~TapePreferencesConfigurationPage() override;

    auto Apply() -> QStringList;
protected:
    void changeEvent(QEvent* event) override;
private:
    // cppcheck-suppress unknownMacro
    Q_DISABLE_COPY_MOVE(TapePreferencesConfigurationPage) // NOLINT
    Ui::TapePreferencesConfigurationPage *ui;
    bool m_langChanged;
    bool m_systemChanged;

    void RetranslateUi();
};

#endif // TAPEPREFERENCESCONFIGURATIONPAGE_H
